@@ -21,3 +21,7 @@ from .xnor import xnor
 # # COUNT, SELECT (VARIABLE)
 from .count import count
 from .select import select
+
+# EQV, IMP (SHORTCUTS)
+from .eqv import eqv
+from .imp import imp
